

from fractions import Fraction

def READ_BYTES (PATH):
	with open (PATH, mode = 'rb') as file:
		BYTES = file.read ()
		STRING = BYTES.hex ()
		
		print (BYTES)
		print (STRING)
		
		print (len (STRING))
		print ("BYTE COUNT = ", Fraction (len (STRING), 2))




from .ED448 import ED448

def DUOM (GROUP):
	import click
	@GROUP.group ("DUOM")
	def GROUP ():
		pass
		
	import click
	@GROUP.command ("")
	def EXAMPLE ():	
		print ("START")



		return;
		
	ED448 (GROUP)

	return;





'''
	from DUOM.ED448.PUBLIC_KEY.SCAN import SCAN_PUBLIC_KEY
	[ PUBLIC_KEY, PUBLIC_KEY_BYTES, PUBLIC_KEY_STRING ] = SCAN_PUBLIC_KEY (PATH)
'''


#
#	IMPORT A PUBLIC OR PRIVATE KEY:
#
#		https://pycryptodome.readthedocs.io/en/latest/src/public_key/ecc.html#Crypto.PublicKey.ECC.import_key
#

from Crypto.PublicKey 	import ECC

from fractions 			import Fraction

def SCAN_PUBLIC_KEY (PATH):
	with open (PATH, mode = 'rb') as file:
		PUBLIC_KEY_BYTES = file.read ()
		
		PUBLIC_KEY			= ECC.import_key (
			PUBLIC_KEY_BYTES,
			curve_name		= "Ed448"
		)
		
		PUBLIC_KEY_STRING = PUBLIC_KEY_BYTES.hex ()

		return [ 
			PUBLIC_KEY, 
			PUBLIC_KEY_BYTES, 
			PUBLIC_KEY_STRING 
		];








from .KEG 		import KEG
from .DUOM 		import DUOM
#from .BYTES 	import BYTES


def START ():
	import click
	@click.group ()
	def GROUP ():
		pass


	import click
	@click.command ("example")
	def EXAMPLE ():	
		print ("EXAMPLE")

		return;
	GROUP.add_command (EXAMPLE)

	KEG (GROUP)
	DUOM (GROUP)
	#BYTES (GROUP)

	GROUP ()




#





'''
	from DUOM.ED448.PRIVATE_KEY.BUILD import BUILD_PRIVATE_KEY
	[ PRIVATE_KEY, PRIVATE_KEY_EXPORT ] = BUILD_PRIVATE_KEY (SEED, FORMAT)
'''

'''
	SEED:
		4986888b11358bf3d541b41eea5daece1c6eff64130a45fc8b9ca48f3e0e02463c99c5aedc8a847686d669b7d547c18fe448fc5111ca88f4e8
		5986888b11358bf3d541b41eea5daece1c6eff64130a45fc8b9ca48f3e0e02463c99c5aedc8a847686d669b7d547c18fe448fc5111ca88f4e8
		
		4986888B11358BF3D541B41EEA5DAECE1C6EFF64130A45FC8B9CA48F3E0E02463C99C5AEDC8A847686D669B7D547C18FE448FC5111CA88F4E8
		
	FORMAT:
		DER
		PEM
'''
from Crypto.PublicKey.ECC 	import EccKey

def WRITE (PATH, PRIVATE_KEY_STRING):
	import os.path
	if (os.path.exists (PATH)):
		print ("PUBLIC KEY ALREADY EXISTS, EXITING.");
		exit ()
		return False;
	
	f = open (PATH, 'wb')
	# f = open (PATH, 'wt')
	f.write (PRIVATE_KEY_STRING)
	f.close ()
	
	return True;


def BUILD_PRIVATE_KEY (
	SEED, 
	FORMAT, 
	
	PATH = ""
):	
	SEED_BYTES = bytes.fromhex (SEED)
	PRIVATE_KEY			= EccKey (
		curve 			= "Ed448", 
		seed 			= SEED_BYTES
	)
	PRIVATE_KEY_STRING 	= PRIVATE_KEY.export_key (format = FORMAT)
	#print ("PRIVATE STRING:", PRIVATE_KEY_STRING)
	
	if (len (PATH) >= 1):
		WRITE (PATH, PRIVATE_KEY_STRING)

	#print (PRIVATE_KEY, PRIVATE_KEY_STRING)
	
	return [ PRIVATE_KEY, PRIVATE_KEY_STRING ] 







from flask import Flask

from QR.GENERATE import GENERATE_QR

def START ():
	app = Flask (__name__)

	@app.route ("/")
	def hello_world ():
		return "<p>Hello, World!</p>"
		
	@app.route ("/QR")
	def QR ():
		QR_CODE = GENERATE_QR (
			STRING = 'THIS IS A QR CODE MESSAGE!'
		)
	
		return f"""
<body style="background: #222">
	<img src='{ QR_CODE }' />
</body>
		"""
		
	app.run ()




def KEG (GROUP):
	import click
	@GROUP.group ("KEG")
	def GROUP ():
		pass
		
	import click
	@GROUP.command ("START")
	def EXAMPLE ():	
		print ("START")

		from KEG import START
		START ()

		return;

	return;